@@ -332,68 +332,28 @@ use warnings;
 use URI::Escape;
 use HTML::Entities ();
 use LWP::UserAgent ();
-use vars qw(@ISA @EXPORT);
+use parent 'StreamFinder::_Class';
 
 my $DEBUG = 0;
-my $bummer = ($^O =~ /MSWin/);
-my $FAST = 0;
-my %uops = ();
-my @userAgentOps = ();
-
-require Exporter;
-
-@ISA = qw(Exporter);
-@EXPORT = qw(get getURL getType getID getTitle getIconURL getIconData getImageURL getImageData);
 
 sub new
 {
 	my $class = shift;
 	my $url = shift;
 
-	my $self = {};
 	return undef  unless ($url);
 
-	my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
-	$homedir ||= $ENV{'LOGDIR'}  if ($ENV{'LOGDIR'});
-	$homedir =~ s#[\/\\]$##;
-	foreach my $p ("${homedir}/.config/StreamFinder/config", "${homedir}/.config/StreamFinder/Youtube/config") {
-		if (open IN, $p) {
-			my ($atr, $val);
-			while (<IN>) {
-				chomp;
-				next  if (/^\s*\#/o);
-				($atr, $val) = split(/\s*\=\>\s*/o, $_, 2);
-				eval "\$uops{$atr} = $val";
-			}
-			close IN;
-		}
-	}
-	foreach my $i (qw(agent from conn_cache default_headers local_address ssl_opts max_size
-			max_redirect parse_head protocols_allowed protocols_forbidden requests_redirectable
-			proxy no_proxy)) {
-		push @userAgentOps, $i, $uops{$i}  if (defined $uops{$i});
-	}
-	push (@userAgentOps, 'agent', 'Mozilla/5.0 (X11; Linux x86_64; rv:68.0) Gecko/20100101 Firefox/68.0')
-			unless (defined $uops{'agent'});
-	$uops{'timeout'} = 10  unless (defined $uops{'timeout'});
-	$uops{'secure'} = 0  unless (defined $uops{'secure'});
-	$uops{'noiframes'} = 0  unless (defined $uops{'noiframes'});
-	$DEBUG = $uops{'debug'}  if (defined $uops{'debug'});
-	$FAST = $uops{'fast'}  if (defined $uops{'fast'});
+	my $self = $class->SUPER::new('Youtube', @_);
+	$DEBUG = $self->{'debug'}  if (defined $self->{'debug'});
+	$self->{'noiframes'} = 0  unless (defined $self->{'noiframes'});
 
 	while (@_) {
-		if ($_[0] =~ /^\-?debug$/o) {
+		if ($_[0] =~ /^\-?fast$/o) {
 			shift;
-			$DEBUG = (defined($_[0]) && $_[0] =~/^[0-9]$/) ? shift : 1;
-		} elsif ($_[0] =~ /^\-?fast$/o) {
-			shift;
-			$FAST = (defined($_[0]) && $_[0] =~/^[0-9]$/) ? shift : 1;
+			$self->{'fast'} = (defined($_[0]) && $_[0] =~/^[0-9]$/) ? shift : 1;
 		} elsif ($_[0] =~ /^\-?noiframes$/o) {
 			shift;
-			$uops{'noiframes'} = (defined $_[0]) ? shift : 1;
-		} elsif ($_[0] =~ /^\-?secure$/o) {
-			shift;
-			$uops{'secure'} = (defined $_[0]) ? shift : 1;
+			$self->{'noiframes'} = (defined $_[0]) ? shift : 1;
 		} else {
 			shift;
 		}
@@ -413,32 +373,21 @@ $url2fetch =~ s/www\.youtube\.com/youtube\.be/;  #WWW.YOUTUBE.COM SEEMS TO NOW B
 		$url2fetch = 'https://youtube.be/watch?v=' . $url;
 	}
 	print STDERR "-1 FETCHING URL=$url= VIA youtube-dl: ID=".$self->{'id'}."=\n"  if ($DEBUG);
-	$self->{'title'} = '';
-	$self->{'artist'} = '';
-	$self->{'album'} = '';
-	$self->{'description'} = '';
-	$self->{'created'} = '';
-	$self->{'year'} = '';
 	$self->{'genre'} = 'Video';
-	$self->{'iconurl'} = '';
-	$self->{'streams'} = [];
-	$self->{'cnt'} = 0;
-	$self->{'Url'} = '';
-	$self->{'playlist'} = '';
 	$self->{'albumartist'} = $url2fetch;
 
 	#FIRST:  GET STREAMS, THUMBNAIL, ETC. FROM youtube-dl:
 
 	my $ytdlArgs = '--get-url --get-thumbnail --get-title --get-description -f "'
-			. ((defined $uops{'format'}) ? $uops{'format'} : 'mp4')
-			. '" ' . ((defined $uops{'youtube-dl-args'}) ? $uops{'youtube-dl-args'} : '');
+			. ((defined $self->{'format'}) ? $self->{'format'} : 'mp4')
+			. '" ' . ((defined $self->{'youtube-dl-args'}) ? $self->{'youtube-dl-args'} : '');
 	my $try = 0;
 	my ($more, @ytdldata, @ytStreams);
 RETRYIT:
 	$_ = '';
-	if (defined($uops{'userid'}) && defined($uops{'userpw'})) {  #USER HAS A LOGIN CONFIGURED:
-		my $uid = $uops{'userid'};
-		my $upw = $uops{'userpw'};
+	if (defined($self->{'userid'}) && defined($self->{'userpw'})) {  #USER HAS A LOGIN CONFIGURED:
+		my $uid = $self->{'userid'};
+		my $upw = $self->{'userpw'};
 		$_ = `youtube-dl --username "$uid" --password "$upw" $ytdlArgs "$url"`;
 	} else {
 		$_ = `youtube-dl $ytdlArgs "$url"`;
@@ -446,22 +395,22 @@ RETRYIT:
 	print STDERR "--TRY($try of 1): youtube-dl returned=$_= ARGS=$ytdlArgs=\n"  if ($DEBUG);
 	@ytdldata = split /\r?\n/s;
 	unless ($try || scalar(@ytdldata) > 0) {  #IF NOTHING FOUND, RETRY WITHOUT THE SPECIFIC FILE-FORMAT:
-		unless ($uops{'-noiframes'}) {
+		unless ($self->{'noiframes'}) {
 			print STDERR "..1a:See if we have a StreamFinder-supported URL in 1st iframe?...\n"  if ($DEBUG);
 			my $embedded_video;
 			my $html = '';
-			my $ua = LWP::UserAgent->new(@userAgentOps);		
-			$ua->timeout($uops{'timeout'});
+			my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
+			$ua->timeout($self->{'timeout'});
 			$ua->max_size(1024);  #LIMIT FETCH-SIZE TO AVOID INFINITELY DOWNLOADING A STREAM!
 			$ua->cookie_jar({});
 			$ua->env_proxy;
 		 	my $response = $ua->get($url);
 		 	$html = $response->decoded_content  if ($response->is_success);
-		 	if ($html =~ /\<\!DOCTYPE\s+(?:html|text)/) {  #IF WE'RE AN HTML DOCK (NOT A STREAM!), THEN FETCH THE WHOLE THING:
+		 	if ($html =~ /\<\!DOCTYPE\s+(?:html|text)/i) {  #IF WE'RE AN HTML DOCK (NOT A STREAM!), THEN FETCH THE WHOLE THING:
 				$ua->max_size(undef);  #(NOW OK TO FETCH THE WHOLE DOCUMENT)
 			 	my $response = $ua->get($url);
 			 	$html = $response->decoded_content  if ($response->is_success);
-				while ($html && $html =~ m#\<iframe([^\>]+)#s) {
+				while ($html && $html =~ s#\<iframe([^\>]+)\>##s) {
 					my $one = $1;
 					my $embeddedURL = ($one =~ m#\"(https?\:\/\/[^\"]+)#s) ? $1 : '';
 					print STDERR "--embedded IFRAME url=$embeddedURL=\n"  if ($DEBUG);
@@ -494,7 +443,7 @@ RETRYIT:
 		$_ = shift @ytdldata;
 		$more = 0  unless (m#^https?\:\/\/#o);
 		if ($more) {
-			push @ytStreams, $_  unless ($uops{'secure'} && $_ !~ /^https/o);
+			push @ytStreams, $_  unless ($self->{'secure'} && $_ !~ /^https/o);
 		} else {
 			$self->{'description'} .= $_ . ' ';
 		}
@@ -511,10 +460,10 @@ RETRYIT:
 
 	#NOW MANUALLY SCAN PAGE TO TRY TO GET artist, description, year, ETC. DIRECTLY FROM PAGE (IF A YOUTUBE SITE):
 
-	unless ($FAST || $url2fetch !~ /\b(?:youtube\.|youtu.be|ytimg\.)\b/) {
+	unless ($self->{'fast'} || $url2fetch !~ /\b(?:youtube\.|youtu.be|ytimg\.)\b/) {
 		print STDERR "-2 FETCHING SCREEN URL=$url2fetch= ID=".$self->{'id'}."=\n"  if ($DEBUG);
-		my $ua = LWP::UserAgent->new(@userAgentOps);		
-		$ua->timeout($uops{'timeout'});
+		my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
+		$ua->timeout($self->{'timeout'});
 		$ua->cookie_jar({});
 		$ua->env_proxy;
 		my $html = '';
@@ -551,7 +500,8 @@ RETRYIT:
 	$self->{'imageurl'} = $self->{'iconurl'};
 	$self->{'Url'} = ($self->{'cnt'} > 0) ? $self->{'streams'}->[0] : '';
 	print STDERR "-count=".$self->{'cnt'}."= iconurl=".$self->{'iconurl'}."=\n"  if ($DEBUG);
-	print STDERR "--SUCCESS: stream url=".$self->{'Url'}."=\n"  if ($DEBUG);
+	print STDERR "--SUCCESS: 1st stream=".$self->{'Url'}."= total=".$self->{'total'}."=\n"
+			if ($DEBUG && $self->{'cnt'} > 0);
 	if ($self->{'description'} =~ /\w/) {
 		$self->{'description'} =~ s/\s+$//;
 	} else {
@@ -570,147 +520,6 @@ RETRYIT:
 	return $self;
 }
 
-sub get
-{
-	my $self = shift;
-
-	return wantarray ? @{$self->{'streams'}} : $self->{'Url'};
-}
-
-sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELIABILITY:
-{
-	my $self = shift;
-	my $arglist = (defined $_[0]) ? join('|',@_) : '';
-	my $idx = ($arglist =~ /\b\-?random\b/) ? int rand scalar @{$self->{'streams'}} : 0;
-	if (($arglist =~ /\b\-?nopls\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls)$/i)
-			|| ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8?)$/i)) {
-		my $plType = $1;
-		my $firstStream = ${$self->{'streams'}}[$idx];
-		print STDERR "-YT:getURL($idx): NOPLAYLISTS and (".${$self->{'streams'}}[$idx].")\n"  if ($DEBUG);
-		my $ua = LWP::UserAgent->new(@userAgentOps);		
-		$ua->timeout($uops{'timeout'});
-		$ua->cookie_jar({});
-		$ua->env_proxy;
-		my $html = '';
-		my $response = $ua->get($firstStream);
-		if ($response->is_success) {
-			$html = $response->decoded_content;
-		} else {
-			print STDERR $response->status_line  if ($DEBUG);
-			my $no_wget = system('wget','-V');
-			unless ($no_wget) {
-				print STDERR "\n..trying wget...\n"  if ($DEBUG);
-				$html = `wget -t 2 -T 20 -O- -o /dev/null \"$firstStream\" 2>/dev/null `;
-			}
-		}
-		my @lines = split(/\r?\n/, $html);
-		my @plentries = ();
-		my $firstTitle = '';
-		my $plidx = ($arglist =~ /\b\-?random\b/) ? 1 : 0;
-		if ($plType =~ /pls/i) {  #PLS:
-			foreach my $line (@lines) {
-				if ($line =~ m#^\s*File\d+\=(.+)$#o) {
-					push (@plentries, $1);
-				} elsif ($line =~ m#^\s*Title\d+\=(.+)$#o) {
-					$firstTitle ||= $1;
-				}
-			}
-			$self->{'title'} ||= $firstTitle;
-			$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
-			$self->{'title'} = uri_unescape($self->{'title'});
-			print STDERR "-getURL(PLS): title=$firstTitle= pl_idx=$plidx=\n"  if ($DEBUG);
-		} elsif ($arglist =~ /\b\-?noplaylists\b/) {  #m3u*:
-			(my $urlpath = ${$self->{'streams'}}[$idx]) =~ s#[^\/]+$##;
-			foreach my $line (@lines) {
-				if ($line =~ m#^\s*([^\#].+)$#o) {
-					my $urlpart = $1;
-					$urlpart =~ s#^\s+##o;
-					$urlpart =~ s#^\/##o;
-					push (@plentries, ($urlpart =~ m#https?\:#) ? $urlpart : ($urlpath . '/' . $urlpart));
-					last  unless ($plidx);
-				}
-			}
-			print STDERR "-getURL(m3u?): pl_idx=$plidx=\n"  if ($DEBUG);
-		}
-		if ($plidx && $#plentries >= 0) {
-			$plidx = int rand scalar @plentries;
-		} else {
-			$plidx = 0;
-		}
-		$firstStream = (defined($plentries[$plidx]) && $plentries[$plidx]) ? $plentries[$plidx]
-				: ${$self->{'streams'}}[$idx];
-
-		return $firstStream;
-	}
-
-	return ${$self->{'streams'}}[$idx];
-}
-
-sub count
-{
-	my $self = shift;
-	return $self->{'total'};  #TOTAL NUMBER OF PLAYABLE STREAM URLS FOUND.
-}
-
-sub getType
-{
-	my $self = shift;
-	return 'Youtube';  #STATION TYPE (FOR PARENT StreamFinder MODULE).
-}
-
-sub getID
-{
-	my $self = shift;
-	return $self->{'id'};  #VIDEO'S YOUTUBE-ID.
-}
-
-sub getTitle
-{
-	my $self = shift;
-	return $self->{'description'}  if (defined($_[0]) && $_[0] =~ /^\-?(?:long|desc)/i);
-	return $self->{'title'};  #STATION'S TITLE(DESCRIPTION), IF ANY.
-}
-
-sub getIconURL
-{
-	my $self = shift;
-	return $self->{'iconurl'};  #URL TO THE VIDEO'S THUMBNAIL ICON, IF ANY.
-}
-
-sub getIconData
-{
-	my $self = shift;
-	return ()  unless ($self->{'iconurl'});
-	my $ua = LWP::UserAgent->new(@userAgentOps);		
-	$ua->timeout($uops{'timeout'});
-	$ua->cookie_jar({});
-	$ua->env_proxy;
-	my $art_image = '';
-	my $response = $ua->get($self->{'iconurl'});
-	if ($response->is_success) {
-		$art_image = $response->decoded_content;
-	} else {
-		print STDERR $response->status_line  if ($DEBUG);
-		my $no_wget = system('wget','-V');
-		unless ($no_wget) {
-			print STDERR "\n..trying wget...\n"  if ($DEBUG);
-			my $iconUrl = $self->{'iconurl'};
-			$art_image = `wget -t 2 -T 20 -O- -o /dev/null \"$iconUrl\" 2>/dev/null `;
-		}
-	}
-	return ()  unless ($art_image);
-	(my $image_ext = $self->{'iconurl'}) =~ s/^.+\.//;
-	$image_ext =~ s/[^A-Za-z].*$//;
-
-	return ($image_ext, $art_image);
-}
-
-sub getImageURL
-{
-	my $self = shift;
-	return $self->{'imageurl'};  #URL TO THE VIDEO'S BANNER IMAGE, IF ANY.
-}
-
 sub getImageData
 {
 	my $self = shift;
